@@ -34,7 +34,10 @@ import threading
 import time
 from functools import reduce
 
-import ifcfg
+# Use ifaddr instead of ifcfg in order to ensure that we are always
+# able to read outgoing addresses. ifcfg fails to do so on Windows
+# in a non-English locale. This is critical for many of our users.
+import ifaddr
 from six import binary_type, indexbytes, int2byte, iteritems, text_type
 from six.moves import xrange
 
@@ -42,7 +45,7 @@ import enum_compat as enum
 
 __author__ = "Paul Scott-Murphy, William McBrine"
 __maintainer__ = "Jamie Alexandre <jamie@learningequality.org>"
-__version__ = "0.19.9"
+__version__ = "0.19.11"
 __license__ = "LGPL"
 
 
@@ -1712,8 +1715,8 @@ if "ANDROID_ARGUMENT" in os.environ:
 
     AndroidString = autoclass("java.lang.String")
 
-    def get_network_interfaces():
-        interfaces = []
+    def get_all_addresses():
+        addresses = []
         try:
             NetworkInterface = autoclass("java.net.NetworkInterface")
             Inet4Address = autoclass("java.net.Inet4Address")
@@ -1726,28 +1729,16 @@ if "ANDROID_ARGUMENT" in os.environ:
                     # There are no methods for checking IP address type, so check object type.
                     address = ip.getHostAddress()
                     if isinstance(ip, Inet4Address):
-                        interfaces.append({"inet": address, "inet6": ""})
-                    else:
-                        interfaces.append({"inet": "", "inet6": address})
+                        addresses.append(address)
         except Exception as e:
             return []
 
-        return interfaces
-
+        return addresses
 
 else:
 
-    def get_network_interfaces():
-        try:
-            return ifcfg.interfaces().values()
-        except:  # ifcfg throws an Exception if the ip/ifconfig commands are not found
-            return []
-
-
-def get_all_addresses():
-    return list(
-        set(iface["inet"] for iface in get_network_interfaces() if iface["inet"])
-    )
+    def get_all_addresses():
+        return list(set(addr.ip for iface in ifaddr.get_adapters() for addr in iface.ips if addr.is_IPv4))
 
 
 def normalize_interface_choice(choice):
@@ -1796,6 +1787,9 @@ def get_errno(e):
     assert isinstance(e, socket.error)
     return e.args[0]
 
+def get_global_done_wait_time():
+    wait_time = os.getenv('PYTHON_ZEROCONF_GLOBAL_DONE_WAIT_TIME')
+    return float(wait_time) if wait_time else 0.001
 
 class Zeroconf(QuietLogger):
 
@@ -1868,7 +1862,8 @@ class Zeroconf(QuietLogger):
 
     @property
     def done(self):
-        return self._GLOBAL_DONE.wait(0.1)
+        wait_time = get_global_done_wait_time()
+        return self._GLOBAL_DONE.wait(wait_time)
 
     def wait(self, timeout):
         """Calling thread waits for a given number of milliseconds or
